@@ -1,2 +1,3 @@
-library(httptest)
+library(testthat)
+
 test_check('Rpoet')
